@@ -47,6 +47,12 @@ def bootstrap_environment():
         default_config_path = get_base_config()
         shutil.copy(str(default_config_path), str(config_path))
 
+    # copy udfs to eva directory
+    udfs_path = Path(EVA_DEFAULT_DIR + "/udfs/")
+    if not udfs_path.exists():
+        default_udfs_path = EVA_INSTALLATION_DIR + "/udfs/"
+        shutil.copytree(default_udfs_path, str(udfs_path))
+
     with open(config_path, 'r') as ymlfile:
         cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
 
